pub struct WeakChunkStorage {
pub height: u32,
pub min_y: i32,
pub map: IntMap<ChunkPos, Weak<RwLock<Chunk>>>,
}Expand description
A storage for chunks where they’re only stored weakly, so if they’re not actively being used somewhere else they’ll be forgotten.
This is used for shared worlds.
This is relatively cheap to clone since it’s just an IntMap with Weak
pointers.
Fields
height: u32The height of the world.
To get the maximum y position (exclusive), you have to combine this with
Self::min_y.
min_y: i32The lowest y position in the world that can still have blocks placed on it.
This exists because in modern Minecraft versions, worlds can extend below y=0.
map: IntMap<ChunkPos, Weak<RwLock<Chunk>>>Implementations